OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Contacté récemment",
    "Contacts Interaction" : "Interaction des contacts",
    "Manages interaction between accounts and contacts" : "Gère l'interaction entre les comptes et les contacts",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "Recueillir des données sur les interactions des comptes et des contacts et fournir un carnet d'adresses pour les données",
    "Manages interaction between users and contacts" : "Gère l'interaction entre les utilisateurs et les contacts",
    "Collect data about user and contacts interactions and provide an address book for the data" : "Recueillir des données sur les interactions des utilisateurs et des contacts et fournir un carnet d'adresses pour les données"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
